==> nmrium-0.50.1.tgz: package/lib/component/1d/ranges/RangesIntegrals.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { xyIntegral, xyMaxY } from 'ml-spectra-processing';
import { useChartData } from '../../context/ChartContext';
import { useActiveSpectrumRangesViewState } from '../../hooks/useActiveSpectrumRangesViewState';
import useIntegralPath from '../../hooks/useIntegralPath';
import useSpectrum from '../../hooks/useSpectrum';
function Integral(props) {
    const { x, y, max } = props;
    const { integralsScaleRatio } = useActiveSpectrumRangesViewState();
    const path = useIntegralPath({ x, y, max, scaleRatio: integralsScaleRatio });
    return (_jsx("path", { className: "line", stroke: "black", strokeWidth: "1", fill: "none", d: path }));
}
const emptyData = { ranges: {}, info: {}, display: {} };
function RangesIntegrals() {
    const { displayerKey } = useChartData();
    const spectrum = useSpectrum(emptyData);
    const integrals = useIntegrals();
    if (!spectrum.ranges?.values ||
        !spectrum.display.isVisible ||
        spectrum.info?.isFid ||
        !integrals) {
        return null;
    }
    return (_jsx("g", { clipPath: `url(#${displayerKey}clip-chart-1d)`, children: integrals.values.map((integral) => {
            return _jsx(Integral, { ...integral, max: integrals.max }, integral.id);
        }) }));
}
function useIntegrals() {
    const spectrum = useSpectrum();
    const { showIntegrals } = useActiveSpectrumRangesViewState();
    if (!spectrum || !showIntegrals)
        return;
    let max = Number.NEGATIVE_INFINITY;
    const values = [];
    const { data: { x, re }, ranges, } = spectrum;
    for (const range of ranges?.values || []) {
        const { from, to, id } = range;
        const integral = xyIntegral({ x, y: re }, {
            from,
            to,
            reverse: true,
        });
        values.push({ ...integral, id });
        const value = xyMaxY(integral);
        if (value > max)
            max = value;
    }
    return { max, values };
}
export default RangesIntegrals;

==> nmrium-0.55.0.tgz: package/lib/component/1d/ranges/RangesIntegrals.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { xyIntegral, xyMaxY } from 'ml-spectra-processing';
import { useChartData } from '../../context/ChartContext';
import { useActiveSpectrumRangesViewState } from '../../hooks/useActiveSpectrumRangesViewState';
import useIntegralPath from '../../hooks/useIntegralPath';
import useSpectrum from '../../hooks/useSpectrum';
function Integral(props) {
    const { x, y, max, from, to } = props;
    const { integralsScaleRatio } = useActiveSpectrumRangesViewState();
    const path = useIntegralPath({
        x,
        y,
        max,
        scaleRatio: integralsScaleRatio,
        from,
        to,
    });
    return (_jsx("path", { className: "line", stroke: "black", strokeWidth: "1", fill: "none", d: path }));
}
const emptyData = { ranges: {}, info: {}, display: {} };
function RangesIntegrals() {
    const { displayerKey, xDomain: [from, to], } = useChartData();
    const spectrum = useSpectrum(emptyData);
    const integrals = useIntegrals();
    if (!spectrum.ranges?.values ||
        !spectrum.display.isVisible ||
        spectrum.info?.isFid ||
        !integrals) {
        return null;
    }
    return (_jsx("g", { clipPath: `url(#${displayerKey}clip-chart-1d)`, children: integrals.values.map((integral) => {
            return (_jsx(Integral, { ...integral, max: integrals.max, from, to }, integral.id));
        }) }));
}
function useIntegrals() {
    const spectrum = useSpectrum();
    const { showIntegrals } = useActiveSpectrumRangesViewState();
    if (!spectrum || !showIntegrals)
        return;
    let max = Number.NEGATIVE_INFINITY;
    const values = [];
    const { data: { x, re }, ranges, } = spectrum;
    for (const range of ranges?.values || []) {
        const { from, to, id } = range;
        const integral = xyIntegral({ x, y: re }, {
            from,
            to,
            reverse: true,
        });
        values.push({ ...integral, id });
        const value = xyMaxY(integral);
        if (value > max)
            max = value;
    }
    return { max, values };
}
export default RangesIntegrals;
